<?php
/**
 * Theme functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * @package WordPress
 * @subpackage MikeBasic
 */

/**
 * Register widgetized areas
 */
function mikebasic_widgets_init( ) {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'mikebasic' ),
		'id' => 'sidebar',
		'description' => __( 'The main sidebar area', 'mikebasic' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'mikebasic_widgets_init' );

/**
 * Register the navigation menus
 */
if ( function_exists( 'register_nav_menus' ) ):
	register_nav_menus(
		array(
			'navigation' => 'Navigation'
		)
	);
endif;


/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'mikebasic_posted_on' ) ) :
	function mikebasic_posted_on( ) 
	{
		$output = '';
		$output .= '<span class="meta-prep meta-prep-author">Posted on</span>';
		$output .= '&nbsp;<span class="entry-date">' . get_the_date( ) . '</span>';
		$output .= '&nbsp;<span class="meta-sep">by</span>';
		$output .= '&nbsp;<span class="author vcard"><a class="url fn n" href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '" title="' . esc_attr__( 'View all posts by ' . get_the_author( )) . '">' . get_the_author( ) . '</a></span>';
		return $output;
	}
endif;

/**
 * Show the categories and tags
 */
if ( ! function_exists( 'mikebasic_show_terms' ) ) :
	function mikebasic_show_terms( ) 
	{
		$output = '';
		$output .= '<span class="term-links">';
		if ( count( get_the_category( ) ) > 0 ) : 
			$output .= '<span class="cat-links">';
			$output .= __('Categories: ' . get_the_category_list( ', ' ));
			$output .= '</span>';
		endif;
		if ( count( get_the_tags( ) ) > 0 && strlen ( get_the_tag_list() ) > 0 ) : 
			$output .= '<span class="tag-links">';
			$output .= __('Tags: ' . get_the_tag_list( '', ', ', ''));
			$output .= '</span>';
		endif; 
		$output .= '</span>';
		return $output;
	}
endif;

/**
 * Template for comments and pingbacks.
 */ 
if ( ! function_exists( 'mikebasic_comment' ) ) :
	
	function mikebasic_comment( $comment, $args, $depth ) 
	{
		$GLOBALS['comment'] = $comment;
		$output = '';
		$class_array = get_comment_class( );
		$comment_classes = '';
		foreach ($class_array as $key => $value):
			$comment_classes .= $value . ' ';
		endforeach;
		$comment_classes = trim($comment_classes);
		$output .= '<li class="' . $comment_classes . '" id="li-comment-' . get_comment_ID( ) . '">';
		$output .= '<div id="comment-' . get_comment_ID( ) . '">';
		$output .= '<div class="comment-meta">';
		$output .= '<div class="comment-avatar">';
		$output .= $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback' ? '<img src="' . get_bloginfo('template_directory') . '/images/pingback.jpg" alt="" width="40" height="40" />' : get_avatar( $comment, 40 );
		$output .= '</div>';
		$output .= '<div class="comment-author">';
		$output .= $comment->comment_type == 'pingback' ? __('Pingback') : $comment->comment_type == 'trackback' ? __('Trackback') : '';
		$output .= $comment->comment_type !== 'pingback' && $comment->comment_type !== 'trackback' ? get_comment_author_link( ) : '';
		$output .= '</div>';
		$output .= '<div class="comment-date"><a href="' . esc_url( get_comment_link( $comment->comment_ID ) ) . '">' . get_comment_date( ) . ' at ' . get_comment_time( ) . '</a></div>';
		$output .= '</div><!-- .comment-meta -->';
		if ( $comment->comment_approved == '0' ) : 
			$output .= '<h4 class="comment-awaiting-moderation">' . __('Your comment is awaiting moderation.') . '</h4>';
		endif;
		$output .= '<div class="comment-body">';
		$output .= $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback' ? get_comment_author_link( ) . '&nbsp;&#8212;&nbsp;' : '';
		$output .= nl2br(get_comment_text( ));
		$output .= '</div>';
		$output .= '</div><!-- #comment-## -->';
		$output .= '</li>';
		echo $output;
	}
endif;

/**
 * Enable featured image / thumbnails
 */
add_theme_support( 'post-thumbnails', array( 'post','page','events'));

